* Encoding: UTF-8.
/*********************************************************************************************************/
/*                                                                                                                                 */
/* This SPSS program will extract the United States Sentencing Commission's                 */
/* Fentanyl and Fentanyl Analogues: Federal Trends and Trafficking Patterns report file      */
/* and create a SAS                                                                                                      */
/* dataset.                                                                                                                    */
/*                                                                                                                                 */
/* Prior to running the program you must update the DAT file location in the                       */
/* FILE HANDLE DATA / NAME line to correspond to the location of the file on your           */
/* computer.                                                                                                                 */
/*                                                                                                                                 */
/* You must also update the file output location in the SAVE OUTFILE statement at the     */
/* end of the program to correspond to the folder you want the output file to be located.       */
/*                                                                                                                                 */
/*********************************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
/* The last line of this file contains the path to your output '.sav' file */

FILE HANDLE DATA / NAME=".\USSC_Fentanyl.dat" ENCODING="CP1252" / LRECL=118 .

DATA LIST FILE=DATA/
   add_drug_types 1         advert 2                 AGE 3-4               
   aggrole 5                AMENDYR 6-9              analogue_add 10       
   analogue_missing 11      analogue_w_cat 12        border_ship 13        
   co_acc 14                copart_dummy 15          crack_pres 16         
   darkweb 17               distro 18                Drug_Function 19-20   
   DRUGMIN 21-24            dsbi_bol 25              Fake_Pills 26         
   Fake_Type 27-48 (A)      Fent_Cour_Intl 49        Fent_Courier 50       
   fent_missing 51          Fent_Net_Txt 52-77 (A)   fent_w_cat 78         
   fentanyl_add 79          heroin_pres 80           intent_misrep 81      
   international_courier 82   internet 83              intl_mail 84          
   know_yes 85              massmarket 86            meth_pres 87          
   mitrole 88               mixture 89               mj_pres 90            
   MONSEX 91                multidrug 92             NEWCIT 93             
   NEWCNVTN 94              NEWEDUC 95               newfentsoc 96         
   NEWRACE 97               overdose_dummy 98        oxy_pres 99           
   powder_pres 100          Prescript 101            PRISDUM 102           
   project_primary 103      reasondbi 104            relief 105            
   reliefdum 106            SAFE 107                 SENSPCAP 108-113      
   SENTRNGE 114             sosdistrict 115          stat851 116           
   WEAPON 117               XCRHISSR 118 .        


FORMATS
  SENSPCAP (F7.2) / .
   
VARIABLE LABELS
   add_drug_types 'add_drug_types'
   advert 'advert'
   AGE 'AGE'
   aggrole 'aggrole'
   AMENDYR 'AMENDYR'
   analogue_add 'analogue_add'
   analogue_missing 'analogue_missing'
   analogue_w_cat 'analogue_w_cat'
   border_ship 'border_ship'
   co_acc 'co_acc'
   copart_dummy 'copart_dummy'
   crack_pres 'crack_pres'
   darkweb 'darkweb'
   distro 'distro'
   Drug_Function 'Drug_Function'
   DRUGMIN 'DRUGMIN'
   dsbi_bol 'dsbi_bol'
   Fake_Pills 'Fake_Pills'
   Fake_Type 'Fake_Type'
   Fent_Cour_Intl 'Fent_Cour_Intl'
   Fent_Courier 'Fent_Courier'
   fent_missing 'fent_missing'
   Fent_Net_Txt 'Fent_Net_Txt'
   fent_w_cat 'fent_w_cat'
   fentanyl_add 'fentanyl_add'
   heroin_pres 'heroin_pres'
   intent_misrep 'intent_misrep'
   international_courier 'international_courier'
   internet 'internet'
   intl_mail 'intl_mail'
   know_yes 'know_yes'
   massmarket 'massmarket'
   meth_pres 'meth_pres'
   mitrole 'mitrole'
   mixture 'mixture'
   mj_pres 'mj_pres'
   MONSEX 'MONSEX'
   multidrug 'multidrug'
   NEWCIT 'NEWCIT'
   NEWCNVTN 'NEWCNVTN'
   NEWEDUC 'NEWEDUC'
   newfentsoc 'newfentsoc'
   NEWRACE 'NEWRACE'
   overdose_dummy 'overdose_dummy'
   oxy_pres 'oxy_pres'
   powder_pres 'powder_pres'
   Prescript 'Prescript'
   PRISDUM 'PRISDUM'
   project_primary 'project_primary'
   reasondbi 'reasondbi'
   relief 'relief'
   reliefdum 'reliefdum'
   SAFE 'SAFE'
   SENSPCAP 'SENSPCAP'
   SENTRNGE 'SENTRNGE'
   sosdistrict 'sosdistrict'
   stat851 'stat851'
   WEAPON 'WEAPON'
   XCRHISSR 'XCRHISSR' .

SAVE OUTFILE='.\USSC_Fentanyl.sav'.
